==> doitoml-0.1.0.tar.gz: doitoml-0.1.0/docs/reference/api.md <==
# API

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml
```

## Constants

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.constants
```

## Types

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.types
```

## Schema

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.schema
```

### Schema Types

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.schema._v0_schema
```

## Errors

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.errors
```

## Entry Points

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.entry_points
```

## Loaders

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.loaders
```

## Configuration

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.sources._config
```

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.config
```

## Sources

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.sources
```

### JSON

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.sources.json._json
```

#### `package.json`

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.sources.json.package
```

### TOML

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.sources.toml._toml
```

#### `pyproject.toml`

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.sources.toml.pyproject
```

### YAML

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.sources.yaml._yaml
```

## `doit` Specific Language

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.dsl
```

## Actors

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.actors._actor
```

## Custom Python Actor

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.actors.py
```

## Updaters

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.updaters._updater
```

### Custom Python Updater

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.updaters.py
```

### `doit.tools` Updaters

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.updaters.doit_tools
```

## Templates

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.templaters._templater
```

### JSON-e

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.templaters.jsone
```

## Utilities

### JSON Utilities

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.utils.json
```

### Log

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.utils.log
```

### Paths

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.utils.path
```

### Custom Python

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.utils.py
```

==> doitoml-0.2.0.tar.gz: doitoml-0.2.0/docs/reference/api.md <==
# API

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml
```

## Constants

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.constants
```

## Types

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.types
```

## Schema

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.schema.validator
```

### Schema Types

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.schema._v0_schema
```

## Errors

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.errors
```

## Entry Points

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.entry_points
```

## Loaders

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.loaders
```

## Configuration

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.sources._config
```

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.config
```

## Sources

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.sources
```

### JSON

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.sources.json._json
```

#### `package.json`

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.sources.json.package
```

### TOML

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.sources.toml._toml
```

#### `pyproject.toml`

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.sources.toml.pyproject
```

### YAML

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.sources.yaml._yaml
```

## `doit` Specific Language

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.dsl
```

## Actors

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.actors._actor
```

## Custom Python Actor

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.actors.py
```

## Updaters

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.updaters._updater
```

### Custom Python Updater

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.updaters.py
```

### `doit.tools` Updaters

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.updaters.doit_tools
```

## Skippers

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.skippers._skipper
```

### Boolean Skippers

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.skippers.bools
```

### Path Skippers

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.skippers.path
```

### Python Skippers

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.skippers.py
```

## Templates

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.templaters._templater
```

### JSON-e

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.templaters.jsone
```

## Utilities

### JSON Utilities

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.utils.json
```

### Log

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.utils.log
```

### Paths

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.utils.path
```

### Custom Python

```{eval-rst}
.. currentmodule:: doitoml
.. automodule:: doitoml.utils.py
```
